diff --git a/aliasDefinition/Data_alias/aliasdefinitionsub/entitygroup/entities/serialletter/entityfields/documenttemplate_id/customproperties/translate4log/property.js b/aliasDefinition/Data_alias/aliasdefinitionsub/entitygroup/entities/serialletter/entityfields/documenttemplate_id/customproperties/translate4log/property.js
index c0db258ec571b6b7da6f75bc85e1de5b549bc94e..1c34e31e8ccd4d848b42fedb4ce04b4600c92bec 100644
--- a/aliasDefinition/Data_alias/aliasdefinitionsub/entitygroup/entities/serialletter/entityfields/documenttemplate_id/customproperties/translate4log/property.js
+++ b/aliasDefinition/Data_alias/aliasdefinitionsub/entitygroup/entities/serialletter/entityfields/documenttemplate_id/customproperties/translate4log/property.js
@@ -5,7 +5,7 @@ import("system.result");
 import("Loghistory_lib");
 
 var params = Translate4LogParams.load();
-var res = newSelect("NAME ")
+var res = newSelect("NAME")
             .from("DOCUMENTTEMPLATE")
             .where("DOCUMENTTEMPLATE.DOCUMENTTEMPLATEID", params.value)
             .cell();
diff --git a/entity/Activity_entity/recordcontainers/db/conditionProcess.js b/entity/Activity_entity/recordcontainers/db/conditionProcess.js
index 73f07d0da71d8c7d925dd4d162f84b819c46d146..a90c77ea69bef0ebc370e9842321a1ffe006c56c 100644
--- a/entity/Activity_entity/recordcontainers/db/conditionProcess.js
+++ b/entity/Activity_entity/recordcontainers/db/conditionProcess.js
@@ -13,10 +13,13 @@ if (vars.exists("$param.RowId_param") && vars.get("$param.RowId_param") && vars.
     var rowIdCond = null;
     if (vars.get("$param.ObjectId_param") == "Person")
     {
-        var personIdSelect = newWhere("CONTACT.PERSON_ID", newSelect("CONTACT.PERSON_ID")
-                                                            .from("CONTACT")
-                                                            .where("CONTACT.CONTACTID", rowId));                                     
-        rowIds = personIdSelect.array();
+        var personIdSelect = newSelect("CONTACT.CONTACTID")
+                                    .from("CONTACT")
+                                    .where("CONTACT.CONTACTID", rowId)
+                                    .and("CONTACT.PERSON_ID", newSelect("CONTACT.PERSON_ID")
+                                                                .from("CONTACT")
+                                                                .where("CONTACT.CONTACTID", rowId));                                     
+        rowIds = personIdSelect.array(db.COLUMN);
     }
     
     var activityLinkSubselect = newSelect("ACTIVITYLINK.ACTIVITY_ID")
diff --git a/entity/AddressType_entity/recordcontainers/db/conditionProcess.js b/entity/AddressType_entity/recordcontainers/db/conditionProcess.js
index ff21b51fb9a1c05da35c77e00a354d2cdde7a488..35e253cd86a8a86cb382ea85ceac7539447d61e8 100644
--- a/entity/AddressType_entity/recordcontainers/db/conditionProcess.js
+++ b/entity/AddressType_entity/recordcontainers/db/conditionProcess.js
@@ -5,21 +5,20 @@ import("KeywordRegistry_basic");
 import("Sql_lib");
 import("Keyword_lib");
 
-var cond = SqlCondition.begin()
-                       .andPrepare("AB_KEYWORD_ENTRY.CONTAINER", $KeywordRegistry.addressType());
+var cond = newWhere("AB_KEYWORD_ENTRY.CONTAINER", $KeywordRegistry.addressType());
 
 
 var usageFilter = vars.get("$param.UsageFilter_param");
 if (usageFilter)
 {
     var keywordAttribute = new KeywordAttribute($KeywordRegistry.addressType(), usageFilter);
-    cond.andAttachPrepared(SqlCondition.begin()
-                                       .andPrepare("AB_KEYWORD_ATTRIBUTERELATION.AB_KEYWORD_ATTRIBUTE_ID", keywordAttribute.id)
-                                       .andPrepare("AB_KEYWORD_ATTRIBUTERELATION." + keywordAttribute.dbField, "1")
-                                       .buildSql("AB_KEYWORD_ENTRY.AB_KEYWORD_ENTRYID in (\n\
-                                                    select AB_KEYWORD_ATTRIBUTERELATION.AB_KEYWORD_ENTRY_ID \n\
-                                                    from AB_KEYWORD_ATTRIBUTERELATION ", null, ")"));
+    
+    cond.and("AB_KEYWORD_ENTRY.AB_KEYWORD_ENTRYID", 
+                newSelect("AB_KEYWORD_ATTRIBUTERELATION.AB_KEYWORD_ENTRY_ID")
+                    .from("AB_KEYWORD_ATTRIBUTERELATION")
+                    .where(["AB_KEYWORD_ATTRIBUTERELATION", keywordAttribute.dbField], "1"),
+            SqlBuilder.IN())
 }
 
-cond = cond.translate("1 = 2");
-result.string(cond);
\ No newline at end of file
+//TODO: use a preparedCondition (.build instead of .toString) when available #1030812 #1034026
+result.string(cond.toString());
\ No newline at end of file
diff --git a/entity/Address_entity/entityfields/defaultaddressid_param/valueProcess.js b/entity/Address_entity/entityfields/defaultaddressid_param/valueProcess.js
index 9c5d394a1a55a336b53ea24c4bbe5cc5afa53be7..4e767b539705036b73d5b9c5e77dd000b3233fbd 100644
--- a/entity/Address_entity/entityfields/defaultaddressid_param/valueProcess.js
+++ b/entity/Address_entity/entityfields/defaultaddressid_param/valueProcess.js
@@ -12,9 +12,10 @@ import("system.vars");
 var contactId = vars.get("$param.ContactId_param");
 if (contactId)
 {
-    var sql = SqlCondition.begin()
-    .andPrepare("CONTACT.CONTACTID", contactId)
-    .buildSql("select CONTACT.ADDRESS_ID from CONTACT");
-    var organisationId = db.cell(sql);
+    var organisation = newSelect("CONTACT.ADDRESS_ID")
+                .from("CONTACT")
+                .where("CONTACT.CONTACTID", contactId)
+
+    var organisationId = sql.cell();
     result.string(organisationId);
 }
\ No newline at end of file
diff --git a/entity/Address_entity/entityfields/organisationandcontactaddresses/children/organisationid_param/valueProcess.js b/entity/Address_entity/entityfields/organisationandcontactaddresses/children/organisationid_param/valueProcess.js
index c4bf0500f2c4d1835300f8dbcb921f28b8917f7c..5af79d4be9b6850ab8d8ec8b820e9dd757706168 100644
--- a/entity/Address_entity/entityfields/organisationandcontactaddresses/children/organisationid_param/valueProcess.js
+++ b/entity/Address_entity/entityfields/organisationandcontactaddresses/children/organisationid_param/valueProcess.js
@@ -12,9 +12,9 @@ import("system.vars");
 var contactId = vars.get("$param.ContactId_param");
 if (contactId)
 {
-    var sql = SqlCondition.begin()
-                          .andPrepare("CONTACT.CONTACTID", contactId)
-                          .buildSql("select CONTACT.ORGANISATION_ID from CONTACT");
-    var organisationId = db.cell(sql);
+    var organisationId = newSelect("CONTACT.ORGANISATION_ID")
+                            .from("CONTACT")
+                            .where("CONTACT.CONTACTID", contactId)
+                            .cell();
     result.string(organisationId);
 }
\ No newline at end of file
diff --git a/entity/Address_entity/recordcontainers/childgroup/query.js b/entity/Address_entity/recordcontainers/childgroup/query.js
index 17e6d413dd07573ab64f90b56924072230038dee..1776a08e6416ed6180c17953fd575c30e9af514e 100644
--- a/entity/Address_entity/recordcontainers/childgroup/query.js
+++ b/entity/Address_entity/recordcontainers/childgroup/query.js
@@ -8,13 +8,15 @@ if (vars.exists("$local.idvalue")) {
     affectedIds = vars.get("$local.idvalue");
 }
 
-result.string(SqlUtils.translateStatementWithQuotes(SqlCondition.begin()
-            .andIn("ADDRESS.ADDRESSID", affectedIds)
-            .buildSql("select \n\
-                        ADDRESS.ADDRESSID as \"_uid_\", \n\
-                        ADDRESS.ADDRESSID, \n\
-                        ADDRESS.ZIP as ZIP, \n\
-                        ADDRESS.CITY as CITY, \n\
-                        ADDRESS.COUNTRY, \n\
-                        ADDRESS.ADDRESS, \n\
-                        ADDRESS.BUILDINGNO from ADDRESS", "", "order by ADDRESS.ADDRESSID")));
\ No newline at end of file
+var addressSelect = newSelect("ADDRESS.ADDRESSID as \"_uid_\", \n\
+                               ADDRESS.ADDRESSID, \n\
+                               ADDRESS.ZIP as ZIP, \n\
+                               ADDRESS.CITY as CITY, \n\
+                               ADDRESS.COUNTRY, \n\
+                               ADDRESS.ADDRESS, \n\
+                               ADDRESS.BUILDINGNO")
+                            .from("ADDRESS")
+                            .where("ADDRESS.ADDRESSID", affectedIds, SqlBuilder.IN())
+                            .orderBy("ADDRESS.ADDRESSID")
+
+result.string(addressSelect.toString());
\ No newline at end of file
diff --git a/entity/Address_entity/recordcontainers/db/conditionProcess.js b/entity/Address_entity/recordcontainers/db/conditionProcess.js
index 3494351fa8201c63d3d4574a6e47c4765d95dd68..c4efac40ae8a5341a729f2731f5dbf1c2ab995f5 100644
--- a/entity/Address_entity/recordcontainers/db/conditionProcess.js
+++ b/entity/Address_entity/recordcontainers/db/conditionProcess.js
@@ -3,19 +3,18 @@ import("system.vars");
 import("system.db");
 import("Sql_lib");
 
-var cond = SqlCondition.begin()
-                       .andPrepareVars("ADDRESS.CONTACT_ID", "$param.ContactId_param");
-                       
+var cond = newWhereIfSet("ADDRESS.CONTACT_ID", "$param.ContactId_param");
+
 var organisationId = vars.get("$param.OrganisationId_param");
 if (organisationId)
 {
-    var organisationContactSql = SqlCondition.begin()
-                                             .andPrepare("CONTACT.ORGANISATION_ID", organisationId)
-                                             .and("CONTACT.PERSON_ID is null")
-                                             .buildSql("select CONTACT.CONTACTID from CONTACT");
-    var organisationContactId = db.cell(organisationContactSql);
-    cond.orPrepare("ADDRESS.CONTACT_ID", organisationContactId);
+    var organisationContactId = newSelect("CONTACT.CONTACTID")
+                                    .from("CONTACT")
+                                    .where("CONTACT.ORGANISATION_ID", organisationId)
+                                    .and("CONTACT.PERSON_ID is null")
+                                    .cell();
+    cond.orIfSet("ADDRESS.CONTACT_ID", organisationContactId);
 }
 
-//TODO: use a preparedCondition (.build instead of .translate) when available #1030812 #1034026
-result.string(cond.translate("1 = 2"));
\ No newline at end of file
+//TODO: use a preparedCondition (.build instead of .toString) when available #1030812 #1034026
+result.string(cond.toString());
\ No newline at end of file
diff --git a/entity/Analyses_entity/entityfields/myturnover/valueProcess.js b/entity/Analyses_entity/entityfields/myturnover/valueProcess.js
index 9c8e5ea68dc50dc8a1b7f3ddb63eeffa651d316f..ceb6e24e39795b72fc8edc5ac556482018eaac3c 100644
--- a/entity/Analyses_entity/entityfields/myturnover/valueProcess.js
+++ b/entity/Analyses_entity/entityfields/myturnover/valueProcess.js
@@ -6,8 +6,9 @@ import("Date_lib");
 import("Sql_lib");
 import("system.SQLTYPES")
 
-var turnover = db.cell(SqlCondition.begin()
-                                   .andPrepare("SALESORDER.SALESORDERDATE", datetime.toDate(vars.get("$sys.date"), "yyyy"), "year(#) = ?", SQLTYPES.INTEGER)
-                                   .buildSql("select sum(NET + VAT) from SALESORDER", "1=2"));
+var turnover = newSelect("sum(NET + VAT)")
+                    .from("SALESORDER")
+                    .where("SALESORDER.SALESORDERDATE", datetime.toDate(vars.get("$sys.date"), "yyyy"), "year(#) = ?", SQLTYPES.INTEGER)
+                    .cell();
                                   
 result.string(turnover);
\ No newline at end of file
diff --git a/entity/Analyses_entity/entityfields/openoverduetasks/onActionProcess.js b/entity/Analyses_entity/entityfields/openoverduetasks/onActionProcess.js
index a4a99abca7e87092c860c0b4345398aaa83615f3..c1012c359510ebd9b660bbb712a5549afd01d591 100644
--- a/entity/Analyses_entity/entityfields/openoverduetasks/onActionProcess.js
+++ b/entity/Analyses_entity/entityfields/openoverduetasks/onActionProcess.js
@@ -1,15 +1,15 @@
+import("system.neon");
+import("system.db");
+import("ActivityTask_lib");
 import("Employee_lib");
 import("system.vars");
-import("system.datetime");
-import("system.db");
-import("system.neon");
-import("Date_lib");
 import("Sql_lib");
 
-var overduetask = db.table(SqlCondition.begin()
-                    .andPrepare("TASK.MATURITY_DATE", vars.get("$sys.date"), "# < ?")
-                    .and("TASK.EDITOR_CONTACT_ID = '" + EmployeeUtils.getCurrentContactId() + "'")
-                    .and("TASK.STATUS NOT IN ('ENDED', 'ENDED-DONE', 'ENDED-ABANDONED')")
-                    .buildSql("select TASKID from TASK", "1=2"));
+var overdueTask = newSelect("TASKID")
+                    .from("TASK")
+                    .where("TASK.MATURITY_DATE", vars.get("$sys.date"), "# < ?")
+                    .and("TASK.EDITOR_CONTACT_ID", EmployeeUtils.getCurrentContactId())
+                    .and("TASK.STATUS", TaskUtils.getEndedStatuses(), SqlBuilder.NOT_IN())
+                    .array(db.COLUMN)
 
-neon.openContext("Task", "TaskFilter_view", overduetask, neon.OPERATINGSTATE_SEARCH, null);
\ No newline at end of file
+neon.openContext("Task", "TaskFilter_view", overdueTask, neon.OPERATINGSTATE_SEARCH, null);
\ No newline at end of file
diff --git a/entity/Analyses_entity/entityfields/overdue_tasks/valueProcess.js b/entity/Analyses_entity/entityfields/overdue_tasks/valueProcess.js
index b179962d57663f5da1740a7c60c44832d0483613..8b14b5b5c7bf93a96604cc9e741a2523a72eeaaa 100644
--- a/entity/Analyses_entity/entityfields/overdue_tasks/valueProcess.js
+++ b/entity/Analyses_entity/entityfields/overdue_tasks/valueProcess.js
@@ -1,15 +1,14 @@
-import("Employee_lib");
-import("system.db");
-import("system.datetime");
-import("system.result");
 import("system.vars");
-import("Date_lib");
+import("Employee_lib");
 import("Sql_lib");
+import("ActivityTask_lib");
+import("system.result");
+
+var overdueTaskCount = newSelect("count(TASKID)")
+                    .from("TASK")
+                    .where("TASK.MATURITY_DATE", vars.get("$sys.date"), "# < ?")
+                    .and("TASK.EDITOR_CONTACT_ID", EmployeeUtils.getCurrentContactId())
+                    .and("TASK.STATUS", TaskUtils.getEndedStatuses(), SqlBuilder.NOT_IN())
+                    .cell()
 
-var overduetask = db.cell(SqlCondition.begin()
-                                   .andPrepare("TASK.MATURITY_DATE", vars.get("$sys.date"), "# < ?")
-                                   .and("TASK.EDITOR_CONTACT_ID = '" + EmployeeUtils.getCurrentContactId() + "'")
-                                   .and("TASK.STATUS NOT IN ('ENDED', 'ENDED-DONE', 'ENDED-ABANDONED')")
-                                   .buildSql("select count(TASKID) from TASK", "1=2"));
-                                                                  
-result.string(overduetask);
+result.string(overdueTaskCount);
\ No newline at end of file
diff --git a/entity/Analyses_entity/entityfields/turnover_forecast/valueProcess.js b/entity/Analyses_entity/entityfields/turnover_forecast/valueProcess.js
index d6f89d038debab8b78a11020bdcc2b989341414d..72d7b1588dc53ebc626e3d3fe4691d195f95e69d 100644
--- a/entity/Analyses_entity/entityfields/turnover_forecast/valueProcess.js
+++ b/entity/Analyses_entity/entityfields/turnover_forecast/valueProcess.js
@@ -6,8 +6,9 @@ import("Date_lib");
 import("Sql_lib");
 import("system.SQLTYPES")
 
-var forecast = db.cell(SqlCondition.begin()
-                                    .andPrepare("FORECAST.DATE_START", datetime.toDate(vars.get("$sys.date"), "yyyy"), "year(#) = ?", SQLTYPES.INTEGER)
-                                    .buildSql("select sum(VOLUME) from FORECAST", "1=2"));
+var forecast = newSelect("sum(VOLUME)")
+                .from("FORECAST")
+                .where("FORECAST.DATE_START", datetime.toDate(vars.get("$sys.date"), "yyyy"), "year(#) = ?", SQLTYPES.INTEGER)
+                .cell();
                                   
 result.string(forecast);
\ No newline at end of file
diff --git a/entity/AnyContact_entity/recordcontainers/db/conditionProcess.js b/entity/AnyContact_entity/recordcontainers/db/conditionProcess.js
index c0688f7572349158469b202d4416f8f856b89fa0..72a71a68054367e4b1bf10e333d5b211785b8d69 100644
--- a/entity/AnyContact_entity/recordcontainers/db/conditionProcess.js
+++ b/entity/AnyContact_entity/recordcontainers/db/conditionProcess.js
@@ -4,7 +4,7 @@ import("system.result");
 import("Sql_lib");
 import("Contact_lib");
 
-var orgContactId;
+var orgContactId = null;
 if (vars.exists("$param.ContactId_param") && vars.get("$param.ContactId_param"))
 {
     var contactId = vars.get("$param.ContactId_param");
@@ -16,19 +16,18 @@ if (vars.exists("$param.ContactId_param") && vars.get("$param.ContactId_param"))
     }
 }
 
-var conditionPrivateOrganisation = SqlCondition.begin()
-                                               .andPrepare("CONTACT.ORGANISATION_ID", "0", "# != ?");
+var conditionPrivateOrganisation = newWhere("CONTACT.ORGANISATION_ID", "0", "# <> ?")
 
 if (vars.getString("$param.WithPrivatePersons_param") == "true")
-    conditionPrivateOrganisation.orSqlCondition(SqlCondition.begin()
-                                                            .andPrepare("CONTACT.ORGANISATION_ID", "0")
-                                                            .and("CONTACT.PERSON_ID is not null")
-                                                );
+{
+    conditionPrivateOrganisation.or(newWhere("CONTACT.ORGANISATION_ID", "0")
+                                        .and("CONTACT.PERSON_ID is not null"));
+}
+    
 
 //exclude private organisation
-var cond = SqlCondition.begin()
-                       .andSqlCondition(conditionPrivateOrganisation)
-                       .andPrepareIfSet("CONTACT.ORGANISATION_ID", orgContactId);
+var cond = newWhereIfSet(conditionPrivateOrganisation)
+               .andIfSet("CONTACT.ORGANISATION_ID", orgContactId);
 
-//TODO: use a preparedCondition (.build instead of .translate) when available #1030812 #1034026
-result.string(cond.translate());
\ No newline at end of file
+//TODO: use a preparedCondition (.build instead of .toString) when available #1030812 #1034026
+result.string(cond.toString());
\ No newline at end of file
diff --git a/entity/AppointmentLink_entity/recordcontainers/db/conditionProcess.js b/entity/AppointmentLink_entity/recordcontainers/db/conditionProcess.js
index a49c8d231adf901a8380b6aca4d1aed941b13c0a..b9a9cafdcba80e3ff11803906bddf17e2423c3b3 100644
--- a/entity/AppointmentLink_entity/recordcontainers/db/conditionProcess.js
+++ b/entity/AppointmentLink_entity/recordcontainers/db/conditionProcess.js
@@ -2,8 +2,7 @@ import("system.db");
 import("system.result");
 import("Sql_lib");
 
-var cond = SqlCondition.begin()
-                       .andPrepareVars("AB_APPOINTMENTLINK.APPOINTMENT_ID", "$param.AppointmentId_param")
+var cond = newWhereIfSet("AB_APPOINTMENTLINK.APPOINTMENT_ID", "$param.AppointmentId_param")
 
-//TODO: use a preparedCondition (.build instead of .translate) when available #1030812 #1034026
-result.string(cond.translate("1 = 1"));
\ No newline at end of file
+//TODO: use a preparedCondition (.build instead of .toString) when available #1030812 #1034026
+result.string(cond.toString());
\ No newline at end of file
diff --git a/entity/Appointment_entity/recordcontainers/jdito/contentProcess.js b/entity/Appointment_entity/recordcontainers/jdito/contentProcess.js
index ad79e4da1a4442679263baee900df37040397eac..5e49c849c4998887a4362d59b9b1d9dfccec05ca 100644
--- a/entity/Appointment_entity/recordcontainers/jdito/contentProcess.js
+++ b/entity/Appointment_entity/recordcontainers/jdito/contentProcess.js
@@ -10,7 +10,7 @@ import("system.eMath");
 import("system.util");
 import("system.neon");
 
-var cond = SqlCondition.begin();
+var appointmentSelect = newSelect("APPOINTMENT_ID").from("AB_APPOINTMENTLINK");
 var appointmentUids;
 
 if(vars.get("$local.idvalues") != null && vars.get("$local.idvalues") != "")
@@ -23,10 +23,8 @@ else if(vars.getString("$param.LinkedAppointmentsFromDashlet_param"))
 {
     var contactid = EmployeeUtils.getCurrentContactId();
     
-    cond.andPrepareIfSet("AB_APPOINTMENTLINK.OBJECT_ROWID", contactid)
-
-    appointmentUids = db.table(cond.buildSql("select APPOINTMENT_ID from AB_APPOINTMENTLINK"));
-    result.object(buildEntriesFromUids(appointmentUids));
+    appointmentSelect.whereIfSet("AB_APPOINTMENTLINK.OBJECT_ROWID", contactid)
+    result.object(buildEntriesFromUids(appointmentSelect.table()));
 }
 
 /**
@@ -34,10 +32,8 @@ else if(vars.getString("$param.LinkedAppointmentsFromDashlet_param"))
  */
 else if(vars.getString("$param.LinkedObjectId_param") != undefined)
 {
-    cond.andPrepareVars("AB_APPOINTMENTLINK.OBJECT_ROWID", "$param.LinkedObjectId_param")
-   
-    appointmentUids = db.table(cond.buildSql("select APPOINTMENT_ID from AB_APPOINTMENTLINK"));
-    result.object(buildEntriesFromUids(appointmentUids));
+    appointmentSelect.whereIfSet("AB_APPOINTMENTLINK.OBJECT_ROWID", "$param.LinkedObjectId_param")
+    result.object(buildEntriesFromUids(appointmentSelect.table()));
 }
 /**
  * Will be used, if the user is operating the calendar.
diff --git a/entity/Appointment_entity/recordcontainers/jdito/onDelete.js b/entity/Appointment_entity/recordcontainers/jdito/onDelete.js
index 426f6fef57e738300c2a731a791bd0fc118feca3..cd469c7c5c068e276d44a78ce534f02e8dfd9420 100644
--- a/entity/Appointment_entity/recordcontainers/jdito/onDelete.js
+++ b/entity/Appointment_entity/recordcontainers/jdito/onDelete.js
@@ -18,8 +18,6 @@ if (vars.exists("$param.Entry_param"))
     /**
      * Deletes ApointmentLinks referring to the deleted Appointment.
      */
-    var cond = SqlCondition.begin();
-    cond.andPrepareIfSet("AB_APPOINTMENTLINK.APPOINTMENT_ID", entry[calendars.ID])
-    
-    db.deleteData("AB_APPOINTMENTLINK", cond.build("1 = 2"));
+    newWhereIfSet("AB_APPOINTMENTLINK.APPOINTMENT_ID", entry[calendars.ID])
+            .deleteData(true, "AB_APPOINTMENTLINK")
 }
\ No newline at end of file
diff --git a/entity/Appointment_entity/recordcontainers/jdito/rowCountProcess.js b/entity/Appointment_entity/recordcontainers/jdito/rowCountProcess.js
index 63e41b300e041444be45983da84cc9c3bd51507e..afff252f743faff586199e13333a707e5d52c51e 100644
--- a/entity/Appointment_entity/recordcontainers/jdito/rowCountProcess.js
+++ b/entity/Appointment_entity/recordcontainers/jdito/rowCountProcess.js
@@ -5,14 +5,15 @@ import("system.vars");
 import("system.result");
 
 var rowCount = "0";
-var cond = SqlCondition.begin();
+var cond = newSelect("count(APPOINTMENT_ID)")
+               .from("AB_APPOINTMENTLINK");
 
 if (vars.exists("$local.idvalues") && vars.get("$local.idvalues"))
     rowCount = "1";
 else if (vars.getString("$param.LinkedAppointmentsFromDashlet_param"))
 {
-    cond.andPrepareIfSet("AB_APPOINTMENTLINK.OBJECT_ROWID", EmployeeUtils.getCurrentContactId());
-    rowCount = db.cell(cond.buildSql("select count(APPOINTMENT_ID) from AB_APPOINTMENTLINK", "1=1"));
+    cond.whereIfSet("AB_APPOINTMENTLINK.OBJECT_ROWID", EmployeeUtils.getCurrentContactId());
+    rowCount = cond.cell();
 }
 
 /**
@@ -20,8 +21,8 @@ else if (vars.getString("$param.LinkedAppointmentsFromDashlet_param"))
  */
 else if (vars.getString("$param.LinkedObjectId_param") != undefined)
 {
-    cond.andPrepareVars("AB_APPOINTMENTLINK.OBJECT_ROWID", "$param.LinkedObjectId_param");
-    rowCount = db.cell(cond.buildSql("select count(APPOINTMENT_ID) from AB_APPOINTMENTLINK", "1=1"));
+    cond.whereIfSet("AB_APPOINTMENTLINK.OBJECT_ROWID", "$param.LinkedObjectId_param");
+    rowCount = cond.cell();
 }
 /**
  * Will be used, if the user is operating the calendar.
diff --git a/entity/AttributeRelation_entity/entityfields/value/displayValueProcess.js b/entity/AttributeRelation_entity/entityfields/value/displayValueProcess.js
index 415b66e5b08b02ef55d723874a37a2ea8c83b1c5..e937b57e12a503145c895cff9e185028ce3034f3 100644
--- a/entity/AttributeRelation_entity/entityfields/value/displayValueProcess.js
+++ b/entity/AttributeRelation_entity/entityfields/value/displayValueProcess.js
@@ -8,10 +8,9 @@ import("system.tools");
 import("Sql_lib");
 
 var attrType = vars.get("$field.ATTRIBUTE_TYPE");
-var dropDownDef = db.cell(
-    SqlCondition.begin()
-        .andPrepareVars("AB_ATTRIBUTE.AB_ATTRIBUTEID", "$field.AB_ATTRIBUTE_ID")
-        .buildSql("select DROPDOWNDEFINITION from AB_ATTRIBUTE")
-);
+var dropDownDef = newSelect("DROPDOWNDEFINITION")
+                    .from("AB_ATTRIBUTE")
+                    .whereIfSet("AB_ATTRIBUTE.AB_ATTRIBUTEID", "$field.AB_ATTRIBUTE_ID")
+                    .cell();
 
 result.string(AttributeTypeUtil.getAttributeViewValue(attrType, vars.get("$field.VALUE"), dropDownDef));
diff --git a/entity/AttributeRelation_entity/recordcontainers/jdito/contentProcess.js b/entity/AttributeRelation_entity/recordcontainers/jdito/contentProcess.js
index ced0fcc55c0a894225ac0adc15e4f66c3aeb9572..6b0dc67b6dd1d50ae53d3eaf6f88b90b088ea93b 100644
--- a/entity/AttributeRelation_entity/recordcontainers/jdito/contentProcess.js
+++ b/entity/AttributeRelation_entity/recordcontainers/jdito/contentProcess.js
@@ -33,14 +33,10 @@ var defaultFields = [
 
 //these fields hold the attributeRelation value, depending on the attribute type
 var valueFields = AttributeTypeUtil.getAllDatabaseFields();
-var attributeSql = SqlBuilder.begin()
-    .select(defaultFields.concat(valueFields))
-    .from("AB_ATTRIBUTE")
-    .orderBy("AB_ATTRIBUTE.SORTING asc");
-
-var attributeCond = SqlCondition.begin(); //where-condition (condition for the Attribute)
-var attributeRelationCond = SqlCondition.begin()
-    .and("AB_ATTRIBUTERELATION.AB_ATTRIBUTE_ID = AB_ATTRIBUTE.AB_ATTRIBUTEID"); //condition for the joined values (for AttributeRelation)
+var attributeSql = newSelect(defaultFields.concat(valueFields))
+                    .from("AB_ATTRIBUTE")
+                    .orderBy("AB_ATTRIBUTE.SORTING asc")
+                    .where(); // go into where mode
 
 var possibleAttributes;
 
@@ -51,13 +47,13 @@ if (idvalues)
         showEmpty = false;
     
     if (showEmpty)
-        attributeCond.andPrepare("AB_ATTRIBUTE.AB_ATTRIBUTEID", attrId);
+        attributeSql.and("AB_ATTRIBUTE.AB_ATTRIBUTEID", attrId);
     else
     {
-        attributeCond.andIn("AB_ATTRIBUTERELATION.AB_ATTRIBUTERELATIONID", idvalues.map(function(pId) 
+        attributeSql.andIfSet("AB_ATTRIBUTERELATION.AB_ATTRIBUTERELATIONID", idvalues.map(function(pId) 
         {
             return pId[0] == "," ? pId.split(",")[1] : pId;
-        }));
+        }), SqlBuilder.IN());
         objectRowId = null;
     }
     getTree = false;
@@ -65,41 +61,42 @@ if (idvalues)
 else if (showEmpty || objectRowId)
 {
     if (getTheme)
-        attributeCond.andPrepare("AB_ATTRIBUTE.ATTRIBUTE_TYPE", $AttributeTypes.THEME);
+        attributeSql.and("AB_ATTRIBUTE.ATTRIBUTE_TYPE", $AttributeTypes.THEME);
     else
-        attributeCond.andPrepare("AB_ATTRIBUTE.ATTRIBUTE_TYPE", $AttributeTypes.THEME, "# != ?");
+        attributeSql.and("AB_ATTRIBUTE.ATTRIBUTE_TYPE", $AttributeTypes.THEME, "# != ?");
     
     if (showEmpty)
     {
         possibleAttributes = AttributeUtil.getPossibleAttributes(objectType);
         let filtered = vars.exists("$param.FilteredAttributeIds_param") && vars.getString("$param.FilteredAttributeIds_param");
         
-        attributeCond.andIn("AB_ATTRIBUTE.AB_ATTRIBUTEID", possibleAttributes);
+        attributeSql.andIfSet("AB_ATTRIBUTE.AB_ATTRIBUTEID", possibleAttributes, SqlBuilder.IN());
     }
     if (vars.exists("$param.FilteredAttributeIds_param") && vars.getString("$param.FilteredAttributeIds_param"))
     {
         let filteredIds = JSON.parse(vars.getString("$param.FilteredAttributeIds_param"));
 
-        let filteredCondition = new SqlCondition();
         let filteredIdChildren = AttributeUtil.getAllChildren(filteredIds);
         
-        filteredCondition.andIn("AB_ATTRIBUTE.AB_ATTRIBUTEID", filteredIdChildren);
-        filteredCondition.andPrepare("AB_ATTRIBUTE.ATTRIBUTE_TYPE", $AttributeTypes.COMBOVALUE, "# != ?")
+        let filteredCondition = newWhereIfSet("AB_ATTRIBUTE.AB_ATTRIBUTEID", filteredIdChildren, SqlBuilder.IN())
+                                    .and("AB_ATTRIBUTE.ATTRIBUTE_TYPE", $AttributeTypes.COMBOVALUE, "# != ?");
     
         // return nothing if filteredAttributeIds is an empty array. (--> and 1=2)
-        attributeCond.andSqlCondition(filteredCondition, "1=2");
+        if (filteredIds && filteredIds.length > 0)
+            attributeSql.and(filteredCondition);
     }
 }
 
+var attributeRelationCond = newWhere("AB_ATTRIBUTERELATION.AB_ATTRIBUTE_ID = AB_ATTRIBUTE.AB_ATTRIBUTEID"); //condition for the joined values (for AttributeRelation)
+
 if (objectRowId)
 {
-    attributeRelationCond.andPrepare("AB_ATTRIBUTERELATION.OBJECT_ROWID", objectRowId);
+    attributeRelationCond.and("AB_ATTRIBUTERELATION.OBJECT_ROWID", objectRowId);
     if (objectType)
-        attributeRelationCond.andPrepare("AB_ATTRIBUTERELATION.OBJECT_TYPE", objectType);
+        attributeRelationCond.and("AB_ATTRIBUTERELATION.OBJECT_TYPE", objectType);
 }
 
 
-attributeSql.where(attributeCond);
     
 if (showEmpty)
     attributeSql.leftJoin("AB_ATTRIBUTERELATION", attributeRelationCond);
@@ -117,11 +114,12 @@ if (getTree)
     if (!possibleAttributes)
         possibleAttributes = AttributeUtil.getPossibleAttributes(objectType);
     
-    let minUsages = db.table(SqlCondition.begin()
-        .andIn("AB_ATTRIBUTEUSAGE.AB_ATTRIBUTE_ID", possibleAttributes)
-        .andPrepare("AB_ATTRIBUTEUSAGE.OBJECT_TYPE", objectType)
-        .buildSql("select AB_ATTRIBUTE_ID, MIN_COUNT from AB_ATTRIBUTEUSAGE", "1=2")
-    );
+    let minUsages = newSelect("AB_ATTRIBUTE_ID, MIN_COUNT")
+                        .from("AB_ATTRIBUTEUSAGE")
+                        .whereIfSet("AB_ATTRIBUTEUSAGE.AB_ATTRIBUTE_ID", possibleAttributes)
+                        .and("AB_ATTRIBUTEUSAGE.OBJECT_TYPE", objectType)
+                        .table(true);
+
     minUsages.forEach(function (usage)
     {
         this[usage[0]] = {
@@ -131,7 +129,7 @@ if (getTree)
     }, minCountInsurance);
 }
 
-var attrRelations = db.table(attributeSql.build()).map(
+var attrRelations = attributeSql.table(true).map(
     function (row) 
     {
         var [attrRelId, attrId, attrParentId, attrType, attrName, dropDownDef, comboViewVal, dateNew, userNew, dateEdit, userEdit] = row;
@@ -195,14 +193,17 @@ function _buildAttributeTree (pAttrRelations)
  */
 function _fetchParentAttributes (pAttributeIds, pParentAttributes)
 {
-    var attributeCond = SqlCondition.begin();
+    var attributeCond = newSelect("AB_ATTRIBUTEID, ATTRIBUTE_PARENT_ID, ATTRIBUTE_NAME")
+                            .from("AB_ATTRIBUTE")
+                            .where()
     var nextIds = [];
     pAttributeIds.forEach(function (id)
     {
         if (!(id in this))
-            attributeCond.orPrepare("AB_ATTRIBUTE.AB_ATTRIBUTEID", id);
+            attributeCond.and("AB_ATTRIBUTE.AB_ATTRIBUTEID", id);
     }, attrCatalog);
-    db.table(attributeCond.buildSql("select AB_ATTRIBUTEID, ATTRIBUTE_PARENT_ID, ATTRIBUTE_NAME from AB_ATTRIBUTE", "1=2"))
+    
+    attributeCond.table(true)
         .forEach(function ([attrId, parentId, attrName])
             {
                 this[attrId] = true; //make entry in attrCatalog to avoid duplicates
diff --git a/process/ActivityTask_lib/process.js b/process/ActivityTask_lib/process.js
index 1f427eaa2de6c226344ea2dd81108bb4e174e805..ba99fe25499cef58f32ebeb01474df30d567d37b 100644
--- a/process/ActivityTask_lib/process.js
+++ b/process/ActivityTask_lib/process.js
@@ -290,6 +290,14 @@ TaskUtils.getOpenTaskCount = function(pRowId, pObjectType)
     return parseInt(taskCount);
 }
 
+/**
+ * @return all status keyIds which indicate a ended task
+ */
+TaskUtils.getEndedStatuses = function()
+{
+    return [$KeywordRegistry.taskStatus$ended(), $KeywordRegistry.taskStatus$endedDone(), $KeywordRegistry.taskStatus$endedAbandoned()]
+}
+
 /**
  * Methods used by for tasks.
  * Do not create an instance of this!
diff --git a/process/KeywordRegistry_basic/process.js b/process/KeywordRegistry_basic/process.js
index f3db5255815df2c575c3419e6267213f8181bdac..7a3ea68a86917fab65c943a63ecd9de4a06736f3 100644
--- a/process/KeywordRegistry_basic/process.js
+++ b/process/KeywordRegistry_basic/process.js
@@ -62,6 +62,8 @@ $KeywordRegistry.taskStatus$assigned = function(){return $KeywordRegistry._autoP
 $KeywordRegistry.taskStatus$inProgress = function(){return $KeywordRegistry._autoPad("IN-PROGRESS");};
 $KeywordRegistry.taskStatus$waiting = function(){return $KeywordRegistry._autoPad("WAITING");};
 $KeywordRegistry.taskStatus$ended = function(){return $KeywordRegistry._autoPad("ENDED");};
+$KeywordRegistry.taskStatus$endedDone = function(){return $KeywordRegistry._autoPad("ENDED-DONE");};
+$KeywordRegistry.taskStatus$endedAbandoned = function(){return $KeywordRegistry._autoPad("ENDED-ABANDONED");};
 $KeywordRegistry.taskStatus$customerChecks = function(){return $KeywordRegistry._autoPad("CUSTOMER-CHECKS");};
 
 $KeywordRegistry.taskType = function(){return "TaskType";};
diff --git a/entity/Address_entity/conditionProcess.js b/entity/Address_entity/conditionProcess.js
index 80ab73670379630d15912e5b02b3309e05ad117b..2a2a40bad76b7c7bf6a7845b81df92b5cfa85ee2 100644
--- a/entity/Address_entity/conditionProcess.js
+++ b/entity/Address_entity/conditionProcess.js
@@ -2,5 +2,5 @@ import("Sql_lib");
 import("system.db");
 import("system.result");
 
-//TODO: use a preparedCondition (.build instead of .translate) when available #1030812 #1034026
-result.string(SqlCondition.begin().andPrepareVars("ADDRESS.CONTACT_ID", "$param.ContactId_param").translate("1=1"));  
+//TODO: use a preparedCondition (.build instead of .toString) when available #1030812 #1034026
+result.string(newWhereIfSet("ADDRESS.CONTACT_ID", "$param.ContactId_param").toString());